__description__ = "a module that tests ClassifierData"
__author__ = "Patrick Godwin (patrick.godwin@ligo.org)"
__doc__ = "\n\n".join([__description__, __author__])

#--------------------------------------------------------------------------

import sys
import pytest

import numpy as np

from ligo import segments as ligo_segments

from idq import utils
from idq.io import triggers

#--------------------------------------------------------------------------

#----------------------
#        tests
#----------------------

@pytest.mark.usefixtures('classifierdata')
class TestClassifierData(object):
    """
    Tests several aspects of a base ClassifierData to check basic functionality.
    """
    def test_segments(self, classifierdata_conf):
        test_seg = ligo_segments.segmentlist([ligo_segments.segment(classifierdata_conf['start_time'], classifierdata_conf['end_time'])])
        assert self.classifierdata.segs == test_seg, 'incorrect segments returned'

    def test_pop(self, classifierdata_conf):
        with pytest.raises(KeyError):
            self.classifierdata.pop('test_channel')

    def test_add(self, classifierdata_conf):
        other_start_time = classifierdata_conf['end_time']
        other_end_time = other_start_time + 1000
        other_classifierdata = triggers.ClassifierData(other_start_time, other_end_time)

        with pytest.raises(NotImplementedError):
            self.classifierdata + other_classifierdata
